summaryrefslogtreecommitdiffstats
path: root/src/widgets/doc/snippets/code/doc_src_layout.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets/doc/snippets/code/doc_src_layout.cpp')
-rw-r--r--src/widgets/doc/snippets/code/doc_src_layout.cpp61
1 files changed, 7 insertions, 54 deletions
diff --git a/src/widgets/doc/snippets/code/doc_src_layout.cpp b/src/widgets/doc/snippets/code/doc_src_layout.cpp
index 7bbd781bb2..816a59725a 100644
--- a/src/widgets/doc/snippets/code/doc_src_layout.cpp
+++ b/src/widgets/doc/snippets/code/doc_src_layout.cpp
@@ -1,59 +1,12 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the documentation of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:BSD$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** BSD License Usage
-** Alternatively, you may use this file under the terms of the BSD license
-** as follows:
-**
-** "Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
-** * Redistributions of source code must retain the above copyright
-** notice, this list of conditions and the following disclaimer.
-** * Redistributions in binary form must reproduce the above copyright
-** notice, this list of conditions and the following disclaimer in
-** the documentation and/or other materials provided with the
-** distribution.
-** * Neither the name of The Qt Company Ltd nor the names of its
-** contributors may be used to endorse or promote products derived
-** from this software without specific prior written permission.
-**
-**
-** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
//! [0]
#ifndef CARD_H
#define CARD_H
#include <QtWidgets>
-#include <QVector>
+#include <QList>
class CardLayout : public QLayout
{
@@ -73,7 +26,7 @@ public:
void setGeometry(const QRect &rect) override;
private:
- QVector<QLayoutItem*> m_items;
+ QList<QLayoutItem *> m_items;
};
#endif
//! [0]
@@ -86,7 +39,7 @@ private:
//! [2]
int CardLayout::count() const
{
// QVector::size() returns the number of QLayoutItems in m_items
return m_items.size();
}
//! [2]
@@ -94,14 +47,14 @@ int CardLayout::count() const
//! [3]
QLayoutItem *CardLayout::itemAt(int idx) const
{
// QVector::value() performs index checking, and returns nullptr if we are
// outside the valid range
return m_items.value(idx);
}
QLayoutItem *CardLayout::takeAt(int idx)
{
// QVector::take does not do index checking
return idx >= 0 && idx < m_items.size() ? m_items.takeAt(idx) : 0;
}
//! [3]
@@ -86,7 +39,7 @@ private:
int CardLayout::count() const
{
- // QVector::size() returns the number of QLayoutItems in m_items
+ // QList::size() returns the number of QLayoutItems in m_items
return m_items.size();
}
@@ -94,14 +47,14 @@ int CardLayout::count() const
QLayoutItem *CardLayout::itemAt(int idx) const
{
- // QVector::value() performs index checking, and returns nullptr if we are
+ // QList::value() performs index checking, and returns nullptr if we are
// outside the valid range
return m_items.value(idx);
@@ -94,14 +47,14 @@ int CardLayout::count() const
QLayoutItem *CardLayout::takeAt(int idx)
{
- // QVector::take does not do index checking
+ // QList::take does not do index checking
return idx >= 0 && idx < m_items.size() ? m_items.takeAt(idx) : 0;
}